@@ -33,7 +33,7 @@ function setImages(node, expand, folder)
 {
 // input: the div class = recording_item node
 // Change the images (if there is an image)
-  const expandNodes = node.getElementsByClassName("recording_expander");
+  const expandNodes = node.getElementsByClassName("recording-expander");
   if (expandNodes.length > 0)
     expandNodes[0].src = expand;
   const folderNodes = node.getElementsByClassName("recording_folder");
@@ -62,7 +62,7 @@ class Treeview {
           if (typeof liveEnhanced !== 'undefined') liveEnhanced.domReadySetup();
         imgLoad();
       }
-      sibling.style.display = 'block';
+      sibling.style.display = 'revert-layer';
       updateCookieOnExpand( sibling.id );
     }
     else
@@ -111,9 +111,10 @@ else
   openNodes = [];
 let domChanges = 0;
 for (let z=0; z<openNodes.length; z++){
+  if (!openNodes[z]) continue;  // otherwise throws error for level 0
   let ul = document.getElementById(openNodes[z]);
   if (ul){
-    ul.style.display = 'block';
+    ul.style.display = 'revert-layer';
     if (rec_ids[openNodes[z]] != null && rec_ids[openNodes[z]].length > 0) {
       ul.insertAdjacentHTML("beforeend", await rec_string_d_a(rec_ids[openNodes[z]]));
       rec_ids[openNodes[z]] = [];
@@ -121,7 +122,7 @@ for (let z=0; z<openNodes.length; z++){
     }
     let divRecItem = ul.parentNode.children[0]
     if (divRecItem != null)
-      setImages(divRecItem, "img/minus.png", "img/folder_open.png");
+      setImages(divRecItem, "img/icon_overlay_minus.png", "img/folder_open.png");
   }
 }
 if (domChanges == 1 && typeof liveEnhanced !== 'undefined') liveEnhanced.domReadySetup();
@@ -147,8 +148,8 @@ async function ExpandAll()
   recordingNodes = getElementsByNodeNameClassName(window.document, 'UL', "recordingslist");
   for (idx = 0; idx < recordingNodes.length; idx++) {
     if (recordingNodes[idx].parentNode.className != 'recordings') {
-      recordingNodes[idx].style.display = 'block';
-      openNodes += recordingNodes[idx].id + ","; 
+      recordingNodes[idx].style.display = 'revert-layer';
+      openNodes += recordingNodes[idx].id + ",";
       if (rec_ids[recordingNodes[idx].id] != null && rec_ids[recordingNodes[idx].id].length > 0) {
         recordingNodes[idx].insertAdjacentHTML("beforeend", await rec_string_d_a(rec_ids[recordingNodes[idx].id]));
         rec_ids[recordingNodes[idx].id] = [];
@@ -156,9 +157,9 @@ async function ExpandAll()
       }
     }
   }
-  expandNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording_expander');
+  expandNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording-expander');
   for (idx = 0; idx < expandNodes.length; idx++) {
-    expandNodes[idx].src = "img/minus.png";
+    expandNodes[idx].src = "img/icon_overlay_minus.png";
   }
   folderNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording_folder');
   for (idx = 0; idx < folderNodes.length; idx++) {
@@ -176,9 +177,9 @@ function CollapseAll()
       recordingNodes[idx].style.display = 'none';
     }
   }
-  expandNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording_expander');
+  expandNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording-expander');
   for (idx = 0; idx < expandNodes.length; idx++) {
-    expandNodes[idx].src = "img/plus.png";
+    expandNodes[idx].src = "img/icon_overlay_plus.png";
   }
   folderNodes = getElementsByNodeNameClassName(window.document, 'IMG', 'recording_folder');
   for (idx = 0; idx < folderNodes.length; idx++) {
@@ -192,7 +193,7 @@ var cookieNameRec = "VDR-Live-Recordings-Tree-Open-Nodes";
 document.addEventListener("DOMContentLoaded", function()
 {
   openNodesOnPageLoad();
-}); 
+});
 
 //The following cookie functions are taken from http://www.quirksmode.org/js/cookies.html
 
