@@ -17,101 +17,82 @@ namespace vdrlive {
     static char const * const preloadFiles[] = {
       "css/siteprefs.css",
       "css/styles.css",
-      "img/rounded-box-blue-bl.png",
-      "img/rounded-box-blue-br.png",
-      "img/rounded-box-blue-ml.png",
-      "img/rounded-box-blue-mr.png",
-      "img/rounded-box-blue-tr.png",
-      "img/rounded-box-green-bl.png",
-      "img/rounded-box-blue-tl.png",
-      "img/rounded-box-green-br.png",
-      "img/rounded-box-green-ml.png",
-      "img/rounded-box-green-mr.png",
-      "img/del.png",
-      "img/info-win-t-r.png",
-      "img/info-win-m-l.png",
-      "img/info-win-m-r.png",
-      "img/info-win-b-l.png",
-      "img/info-win-b-r.png",
-      "img/close_red.png",
-      "img/info-win-t-l.png",
-      "img/rounded-box-green-tl.png",
-      "img/rounded-box-green-tr.png",
-      "img/rounded-box-orange-bl.png",
-      "img/rounded-box-orange-br.png",
-      "img/rounded-box-orange-ml.png",
-      "img/rounded-box-orange-mr.png",
-      "img/rounded-box-orange-tl.png",
-      "img/rounded-box-orange-tr.png",
+      "html/back.html",
+      "img/1280x720.png",
+      "img/169.png",
+      "img/1920x1080.png",
+      "img/221.png",
+      "img/3840x2160.png",
+      "img/43.png",
+      "img/4K.png",
+      "img/720x576.png",
+      "img/7680x4320.png",
+      "img/8K.png",
       "img/active.png",
       "img/arrow.png",
-      "img/bg_box_h.png",
-      "img/bg_box_l.png",
-      "img/bg_box_r.png",
-      "img/bg_header_h.png",
-      "img/bg_header_l.png",
-      "img/bg_header_r.png",
-      "img/bg_line.png",
-      "img/bg_line_top.png",
-      "img/bg_tools.png",
-      "img/button_blue.png",
-      "img/button_green.png",
-      "img/button_new.png",
-      "img/button_red.png",
-      "img/button_yellow.png",
-      "img/close.png",
+      "img/arrow_rec.png",
+      "img/del.png",
       "img/edit.png",
+      "img/english.png",
       "img/ffw.png",
       "img/file.png",
       "img/folder_closed.png",
       "img/folder_open.png",
+      "img/german.png",
+      "img/hd.png",
       "img/help.png",
+      "img/icon_overlay_cross.png",
+      "img/icon_overlay_minus.png",
+      "img/icon_overlay_pinned.png",
+      "img/icon_overlay_pin.png",
+      "img/icon_overlay_plus.png",
+      "img/icon_regular_hovered.png",
+      "img/icon_regular.png",
+      "img/icon_small_hovered.png",
+      "img/icon_small.png",
       "img/imdb.png",
       "img/inactive.png",
       "img/logo_login.png",
       "img/logo.png",
-      "img/menu_line_bg.png",
-      "img/minus.png",
       "img/movie.png",
+      "img/NoRecordingErrors.png",
+      "img/NotCheckedForRecordingErrors.png",
       "img/on_dvd.png",
       "img/one_downarrow.png",
       "img/one_uparrow.png",
       "img/pause.png",
+      "img/playlist.png",
       "img/play.png",
-      "img/plus.png",
+      "img/rd.png",
+      "img/RecordingErrors.png",
       "img/record.png",
-      "img/record_timer.png",
-      "img/recording_timer.gif",
+      "img/record_timer_active.png",
+      "img/record_timer_inactive.png",
       "img/reload.png",
+      "img/remote_control.png",
+      "img/resize.png",
       "img/rwd.png",
+      "img/sd.png",
       "img/search.png",
       "img/stop.png",
       "img/stop_update.png",
+      "img/stream_button.png",
+      "img/timer_conflict.png",
       "img/transparent.png",
+      "img/tv.png",
+      "img/ud.png",
       "img/zap.png",
-      "img/remotecontrol.jpg",
-      "img/tv.jpg",
-      "img/arrow_rec.gif",
-      "img/favicon.ico",
-      "img/playlist.png",
-      "img/sd.png",
-      "img/hd.png",
-      "img/rd.png",
-      "img/RecordingErrors.png",
-      "img/NoRecordingErrors.png",
-      "img/NotCheckedForRecordingErrors.png",
       "js/live/browserwin.js",
-      "js/live/vdr_status.js",
-      "js/live/infowin.js",
-      "js/live/header.js",
-      "js/live/liveajax.js",
-      "js/live/hinttips.js",
-      "js/live/pageenhance.js",
       "js/live/createHtml.js",
       "js/live/epg_tt_box.js",
+      "js/live/hinttips.js",
+      "js/live/infowin.js",
+      "js/live/liveajax.js",
+      "js/live/pageenhance.js",
+      "js/live/scrolling.js",
       "js/live/treeview.js",
+      "js/live/vdr_status.js",
       "js/mootools/mootools.v1.11.js",
-      "html/back.html",
       0
     };
 
