@@ -16,6 +16,7 @@
 #include <vdr/videodir.h>
 #include <vdr/config.h>
 #include <vdr/menu.h>
+#include <vdr/svdrp.h>
 
 #define TIMERRECFILE      "/.timer"
 
@@ -184,14 +185,55 @@ Otherwise, the rec tree is re-created from currnet data.
 
   int RecordingsManager::DeleteRecording(cSv recording_hash, std::string *name)
   {
+    LOCK_TIMERS_WRITE;     // must be before LOCK_RECORDINGS_WRITE
+    Timers->SetExplicitModify();
     LOCK_RECORDINGS_WRITE;
     cRecording *recording = const_cast<cRecording *>(RecordingsManager::GetByHash(recording_hash, Recordings));
     if (!recording) return 1;
     if (name) *name = cSv(recording->Name());
 
-    if (recording->IsInUse() ) return 2;
-
+    // check if recording is activ
     std::string l_name(recording->FileName());
+    if (cRecordControl *rc = cRecordControls::GetRecordControl(l_name.c_str())) {
+        // local timer is activ
+        if (cTimer *Timer = rc->Timer()) {
+            isyslog("live: deactivate local timer %s before delete of recording %s", *Timer->ToDescr(), name->c_str());
+            Timer->OnOff();
+            Timers->SetModified();
+        }
+    }
+    else {
+        // remote timer
+        cString TimerId = GetRecordingTimerId(l_name.c_str());
+        if (*TimerId) {
+            int Id;
+            char *RemoteBuf = NULL;
+            cString Remote;
+            if (2 == sscanf(TimerId, "%d@%m[^ \n]", &Id, &RemoteBuf) && Id != 0) {
+                Remote = RemoteBuf;
+                free(RemoteBuf);
+                if (cTimer *Timer = Timers->GetById(Id, Remote)) {
+                    cTimer OldTimer = *Timer;
+                    Timers->SetSyncStateKey(StateKeySVDRPRemoteTimersPoll);
+                    cString ErrorMessage1;
+                    if (HandleRemoteTimerModifications(NULL, Timer, &ErrorMessage1)) { // delete activ timer on remote vdr
+                        isyslog("live: deactivate remote timer %s before delete of recording %s", *Timer->ToDescr(), name->c_str());
+                        Timer->OnOff();
+                        Timers->SetModified();
+                        cString ErrorMessage2;
+                        if (!HandleRemoteTimerModifications(Timer, NULL, &ErrorMessage2)) {  // add deactived timer on remote vdr
+                            esyslog("live: add inactiv remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage2);
+                            return 2;
+                        }
+                    }
+                    else {
+                        esyslog("live: delete of activ remote timer %s failed: %s", *Timer->ToDescr(), *ErrorMessage1);
+                        return 2;
+                    }
+                }
+            }
+        }
+    }
     bool result = recording->Delete();
     Recordings->DelByName(l_name.c_str());
     return result?0:3;
@@ -370,17 +412,17 @@ Otherwise, the rec tree is re-created from currnet data.
 
   bool RecordingsItemPtrCompare::ByDuplicatesName(const RecordingsItemRec * first, const RecordingsItemRec * second)  // return first < second
   {
-           return first->orderDuplicates(second, false);
+    return first->orderDuplicates(second, false);
   }
 
   bool RecordingsItemPtrCompare::ByDuplicates(const RecordingsItemRec * first, const RecordingsItemRec * second)  // return first < second
   {
-          return first->orderDuplicates(second, true);
+    return first->orderDuplicates(second, true);
   }
 
   bool RecordingsItemPtrCompare::ByDuplicatesLanguage(const RecordingsItemRec * first, const RecordingsItemRec * second)
   {
-          return first->orderDuplicates(second, true, true);
+    return first->orderDuplicates(second, true, true);
   }
 
   const char *firstNonPunct(const char *s) {
@@ -727,6 +769,7 @@ int GetNumberOfTsFiles(cSv fileName) {
       m_shortText = cSv(info->ShortText());
       m_description = cSv(info->Description());
       m_channelName = cSv(info->ChannelName());
+      if (info->GetEvent()) m_parentalRating = info->GetEvent()->ParentalRating();
 #if VDRVERSNUM >= 20605
       m_framesPerSecond  = info->FramesPerSecond();
       m_frameWidth = info->FrameWidth();
@@ -754,6 +797,7 @@ int GetNumberOfTsFiles(cSv fileName) {
       if (!is_equal_utf8_sanitized_string(m_shortText, info->ShortText())) return true;
       if (!is_equal_utf8_sanitized_string(m_description, info->Description())) return true;
       if (!is_equal_utf8_sanitized_string(m_channelName, info->ChannelName())) return true;
+      if (info->GetEvent() && m_parentalRating != info->GetEvent()->ParentalRating()) return true;
 #if VDRVERSNUM >= 20605
       if (m_framesPerSecond != info->FramesPerSecond()) return true;
       if (m_frameWidth != info->FrameWidth()) return true;
@@ -775,6 +819,7 @@ int GetNumberOfTsFiles(cSv fileName) {
   {
     m_shortText = cSv(event->ShortText());
     m_description = std::string(cSv(event->Description()));
+    m_parentalRating = event->ParentalRating();
     m_startTime = event->StartTime();
     m_duration = event->Duration() / 60; // duration in minutes
     m_stopRecording = 0;
@@ -792,7 +837,7 @@ int GetNumberOfTsFiles(cSv fileName) {
   }
 
   void RecordingsItemRec::finalize() {
-// everything that can be doen without needing the vdr cRecording object
+// everything that can be done without needing the VDR cRecording object
 // utf8 sanitize all strings
     utf8_sanitize_string(m_name_vdr);
     utf8_sanitize_string(m_shortText);
@@ -1215,9 +1260,8 @@ void AppendScraperData(cToSvConcat<0> &target, cSv s_IMDB_ID, const cTvMedia &s_
 // [0] : ID
     target.appendHex(IdHash());
     target.append("\",\"");
-// [1] : ArchiveDescr()
-//    if (IsArchived()) AppendHtmlEscapedAndCorrectNonUTF8(target, ArchiveDescr());
-    if (StillRecording()) target.append("is_recording");
+// [1] : Still recording
+    if (StillRecording()) target.append("still_recording");
     target.append("\",");
 // scraper data
     AppendScraperData(target, m_s_IMDB_ID, scraperImage(), m_s_videoType, m_s_title, m_s_season_number, m_s_episode_number, m_s_episode_name, m_s_runtime, m_s_release_date);
@@ -1226,7 +1270,7 @@ void AppendScraperData(cToSvConcat<0> &target, cSv s_IMDB_ID, const cTvMedia &s_
     target.appendDateTime(tr("%a,"), StartTime() );  // day of week
     target.concat(' ');
     target.appendDateTime(tr("%b %d %y"), StartTime());  // date
-    target.concat(' ');
+    target.concat(", ");
     target.appendDateTime(tr("%I:%M %p"), StartTime());  // time
     target.append("\", ");
 // RecordingErrors, Icon
@@ -1271,7 +1315,11 @@ void AppendScraperData(cToSvConcat<0> &target, cSv s_IMDB_ID, const cTvMedia &s_
     target.append("\", \"");
 // [15] Short text
     cSv text = ShortText();
-    if (!text.empty() && Name() != text && !((Name().substr(0, 1) == "%" && Name().substr(1) == text)) ) AppendHtmlEscapedAndCorrectNonUTF8(target, text);
+    if (!text.empty()) {
+      cSv::size_type start = Name().find_first_not_of("@% ");
+      if (start != cSv::npos && Name().substr(start) != text)
+        AppendHtmlEscapedAndCorrectNonUTF8(target, text);
+    }
     target.append("\", \"");
 // [16] Description
     AppendTextTruncateOnWord(target, Description(), LiveSetup().GetMaxTooltipChars(), true);
@@ -1293,9 +1341,9 @@ void AppendScraperData(cToSvConcat<0> &target, cSv s_IMDB_ID, const cTvMedia &s_
     int fileSizeMB = FileSizeMB();
     if(fileSizeMB >= 0)
       if (fileSizeMB >= 1000)
-        target.appendFormated(tr("%.1f GB"), (double)fileSizeMB / 1000.);
+        target.appendFormatted(tr("%.1f GB"), (double)fileSizeMB / 1000.);
       else
-        target.appendFormated(tr("%'d MB"), fileSizeMB);
+        target.appendFormatted(tr("%'d MB"), fileSizeMB);
     else
       target.append("&nbsp;");
     target.append("\",");
@@ -1576,7 +1624,7 @@ std::string recordingErrorsHtml(int recordingErrors) {
     result.append(" ");
     result.append(cToSvInt(recordingErrors));
   }
-  result.append("\" width = \"16px\"/> </div>");
+  result.append("\" width=\"16px\"/> </div>");
   return result;
 #else
   return std::string();
