@@ -247,6 +247,7 @@ namespace vdrlive {
       cSv ChannelName() const { return m_channelName; }
       cSv Folder() const { return m_folder; }
       int HierarchyLevels() const { return std::count(m_name_vdr.begin(), m_name_vdr.end(), FOLDERDELIMCHAR); }
+      int ParentalRating() const { return m_parentalRating; }
       double FramesPerSecond(void) const { return m_framesPerSecond; }
       uint16_t FrameWidth(void) const { return m_frameWidth; }
       uint16_t FrameHeight(void) const { return m_frameHeight; }
@@ -309,6 +310,7 @@ namespace vdrlive {
       std::string m_shortText;
       std::string m_description;
       std::string m_channelName;
+      uchar m_parentalRating = 0;
       mutable int m_fileSizeMB = -1;
       time_t m_startTime = 0;
       mutable time_t m_stopRecording = std::numeric_limits<time_t>::max();  // this is an estimate only
@@ -601,7 +603,7 @@ cToSvConcat<N> & StringAppendFrameParams(cToSvConcat<N> &s, const RecordingsItem
   if (itemRec->FrameWidth() && itemRec->FrameHeight() ) {
     s << itemRec->FrameWidth() << 'x' << itemRec->FrameHeight();
     if (itemRec->FramesPerSecond() > 0) {
-      s.appendFormated("/%.2g", itemRec->FramesPerSecond() );
+      s.appendFormatted("/%.2g", itemRec->FramesPerSecond() );
       if (itemRec->ScanType() != stUnknown)
         s.append(1, itemRec->ScanTypeChar());
      }
